<?php
/**
 * Helper functions related to customizer and options.
 *
 * @package Travel_Gem
 */

if ( ! function_exists( 'travel_gem_get_image_sizes_options' ) ) :

	/**
	 * Returns image sizes options.
	 *
	 * @since 1.0.0
	 *
	 * @param bool  $add_disable    True for adding No Image option.
	 * @param array $allowed        Allowed image size options.
	 * @param bool  $show_dimension True to show dimension.
	 * @return array Image size options.
	 */
	function travel_gem_get_image_sizes_options( $add_disable = true, $allowed = array(), $show_dimension = true ) {

		global $_wp_additional_image_sizes;

		$choices = array();
		if ( true === $add_disable ) {
			$choices['disable'] = esc_html__( 'No Image', 'travel-gem-pro' );
		}

		$choices['thumbnail'] = esc_html__( 'Thumbnail', 'travel-gem-pro' );
		$choices['medium']    = esc_html__( 'Medium', 'travel-gem-pro' );
		$choices['large']     = esc_html__( 'Large', 'travel-gem-pro' );
		$choices['full']      = esc_html__( 'Full (original)', 'travel-gem-pro' );

		if ( true === $show_dimension ) {
			foreach ( array( 'thumbnail', 'medium', 'large' ) as $key => $_size ) {
				$choices[ $_size ] = $choices[ $_size ] . ' (' . get_option( $_size . '_size_w' ) . 'x' . get_option( $_size . '_size_h' ) . ')';
			}
		}

		if ( ! empty( $_wp_additional_image_sizes ) && is_array( $_wp_additional_image_sizes ) ) {
			foreach ( $_wp_additional_image_sizes as $key => $size ) {
				$choices[ $key ] = $key;
				if ( true === $show_dimension ) {
					$choices[ $key ] .= ' (' . $size['width'] . 'x' . $size['height'] . ')';
				}
			}
		}

		if ( ! empty( $allowed ) ) {
			foreach ( $choices as $key => $value ) {
				if ( ! in_array( $key, $allowed, true ) ) {
					unset( $choices[ $key ] );
				}
			}
		}

		return $choices;
	}

endif;

if ( ! function_exists( 'travel_gem_get_alignment_options' ) ) :

	/**
	 * Returns alignment options.
	 *
	 * @since 1.0.0
	 *
	 * @param array $allowed Allowed options.
	 *
	 * @return array Options array.
	 */
	function travel_gem_get_alignment_options( $allowed = array() ) {

		$output = array();
		$choices = array(
			'none'   => esc_html_x( 'None', 'alignment', 'travel-gem-pro' ),
			'left'   => esc_html_x( 'Left', 'alignment', 'travel-gem-pro' ),
			'center' => esc_html_x( 'Center', 'alignment', 'travel-gem-pro' ),
			'right'  => esc_html_x( 'Right', 'alignment', 'travel-gem-pro' ),
		);

		if ( ! empty( $allowed ) ) {
			foreach ( $choices as $key => $value ) {
				if ( in_array( $key, $allowed, true ) ) {
					$output[ $key ] = $value;
				}
			}
		} else {
			$output = $choices;
		}

		return $output;
	}

endif;

if ( ! function_exists( 'travel_gem_get_heading_alignment_options' ) ) :

	/**
	 * Returns heading alignment options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function travel_gem_get_heading_alignment_options() {

		return travel_gem_get_alignment_options( array( 'left', 'center', 'right' ) );
	}

endif;

if ( ! function_exists( 'travel_gem_get_numbers_dropdown_options' ) ) :

	/**
	 * Returns numbers dropdown options.
	 *
	 * @since 1.0.0
	 *
	 * @param int $min Min.
	 * @param int $max Max.
	 * @return array Options array.
	 */
	function travel_gem_get_numbers_dropdown_options( $min = 1, $max = 4 ) {

		$output = array();

		if ( $min <= $max ) {
			for ( $i = $min; $i <= $max; $i++ ) {
				$output[ $i ] = $i;
			}
		}

		return $output;
	}

endif;


if ( ! function_exists( 'travel_gem_get_slider_transition_effects_options' ) ) :

	/**
	 * Returns transition effects options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function travel_gem_get_slider_transition_effects_options() {

		$output = array(
			'fade'       => esc_html_x( 'fade', 'transition effect', 'travel-gem-pro' ),
			'fadeout'    => esc_html_x( 'fadeout', 'transition effect', 'travel-gem-pro' ),
			'none'       => esc_html_x( 'none', 'transition effect', 'travel-gem-pro' ),
			'scrollHorz' => esc_html_x( 'scrollHorz', 'transition effect', 'travel-gem-pro' ),
			'tileSlide'  => esc_html_x( 'tileSlide', 'transition effect', 'travel-gem-pro' ),
			'tileBlind'  => esc_html_x( 'tileBlind', 'transition effect', 'travel-gem-pro' ),
			'flipHorz'   => esc_html_x( 'flipHorz', 'transition effect', 'travel-gem-pro' ),
			'flipVert'   => esc_html_x( 'flipVert', 'transition effect', 'travel-gem-pro' ),
			'shuffle'    => esc_html_x( 'shuffle', 'transition effect', 'travel-gem-pro' ),
		);

		if ( ! empty( $output ) ) {
			ksort( $output );
		}

		return $output;
	}

endif;

if ( ! function_exists( 'travel_gem_get_site_layout_options' ) ) :

	/**
	 * Returns site layout options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function travel_gem_get_site_layout_options() {

		$output = array(
			'fluid' => esc_html__( 'Fluid', 'travel-gem-pro' ),
			'boxed' => esc_html__( 'Boxed', 'travel-gem-pro' ),
		);

		return $output;
	}

endif;

if ( ! function_exists( 'travel_gem_get_custom_header_layout_options' ) ) :

	/**
	 * Returns custom header layout options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function travel_gem_get_custom_header_layout_options() {

		$output = array(
			'1' => esc_html__( 'Default', 'travel-gem-pro' ),
			'2' => esc_html__( 'Small Header', 'travel-gem-pro' ),
		);

		return $output;
	}

endif;

if ( ! function_exists( 'travel_gem_get_global_layout_options' ) ) :

	/**
	 * Returns global layout options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function travel_gem_get_global_layout_options() {

		$output = array(
			'left-sidebar'            => esc_html__( 'Left Sidebar', 'travel-gem-pro' ),
			'right-sidebar'           => esc_html__( 'Right Sidebar', 'travel-gem-pro' ),
			'three-columns'           => esc_html__( '3 Columns (Secondary - Content - Primary)', 'travel-gem-pro' ),
			'three-columns-pcs'       => esc_html__( '3 Columns (Primary - Content - Secondary)', 'travel-gem-pro' ),
			'three-columns-cps'       => esc_html__( '3 Columns (Content - Primary - Secondary)', 'travel-gem-pro' ),
			'three-columns-psc'       => esc_html__( '3 Columns (Primary - Secondary - Content)', 'travel-gem-pro' ),
			'three-columns-pcs-equal' => esc_html__( '3 Columns (Equal Primary - Content - Secondary)', 'travel-gem-pro' ),
			'three-columns-scp-equal' => esc_html__( '3 Columns (Equal Secondary - Content - Primary)', 'travel-gem-pro' ),
			'no-sidebar'              => esc_html__( 'No Sidebar', 'travel-gem-pro' ),
		);

		return $output;
	}

endif;

if ( ! function_exists( 'travel_gem_get_archive_layout_options' ) ) :

	/**
	 * Returns archive layout options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function travel_gem_get_archive_layout_options() {

		$output = array(
			'grid'   => esc_html__( 'Grid', 'travel-gem-pro' ),
			'simple' => esc_html__( 'Simple', 'travel-gem-pro' ),
		);

		return $output;
	}

endif;

if ( ! function_exists( 'travel_gem_get_button_type_options' ) ) :

	/**
	 * Returns button type options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function travel_gem_get_button_type_options() {

		$output = array(
			'rectangle' => esc_html__( 'Rectangle', 'travel-gem-pro' ),
			'curved'    => esc_html__( 'Curved', 'travel-gem-pro' ),
		);

		return $output;
	}

endif;

if ( ! function_exists( 'travel_gem_get_header_layout_options' ) ) :

	/**
	 * Returns header layout options.
	 *
	 * @since 1.0.0
	 *
	 * @param bool $add_default Whether to add default or not.
	 * @return array Options array.
	 */
	function travel_gem_get_header_layout_options( $add_default = false ) {

		$output = array(
			'1' => array(
				'label' => esc_html__( 'One', 'travel-gem-pro' ),
				'url'   => get_template_directory_uri() . '/images/header/layout-1.png',
				),
			'2' => array(
				'label' => esc_html__( 'Two', 'travel-gem-pro' ),
				'url'   => get_template_directory_uri() . '/images/header/layout-2.png',
				),
			'3' => array(
				'label' => esc_html__( 'Three', 'travel-gem-pro' ),
				'url'   => get_template_directory_uri() . '/images/header/layout-3.png',
				),
			'4' => array(
				'label' => esc_html__( 'Four', 'travel-gem-pro' ),
				'url'   => get_template_directory_uri() . '/images/header/layout-4.png',
				),
			);

		if ( true === $add_default ) {
			$item = array(
				'label' => esc_html__( 'Default', 'travel-gem-pro' ),
				'url'   => get_template_directory_uri() . '/images/header/layout-default.png',
				);
			array_unshift( $output, $item );
		}

		return $output;
	}

endif;

if ( ! function_exists( 'travel_gem_get_color_scheme_options' ) ) :

	/**
	 * Returns color scheme options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function travel_gem_get_color_scheme_options() {

		$output = array(
			'default'     => esc_html__( 'Default', 'travel-gem-pro' ),
			'black'       => esc_html__( 'Black', 'travel-gem-pro' ),
			'blue'        => esc_html__( 'Blue', 'travel-gem-pro' ),
			'brown'       => esc_html__( 'Brown', 'travel-gem-pro' ),
			'cyan'        => esc_html__( 'Cyan', 'travel-gem-pro' ),
			'dark-blue'   => esc_html__( 'Dark Blue', 'travel-gem-pro' ),
			'dark-green'  => esc_html__( 'Dark Green', 'travel-gem-pro' ),
			'dark-purple' => esc_html__( 'Dark Purple', 'travel-gem-pro' ),
			'light-green' => esc_html__( 'Light Green', 'travel-gem-pro' ),
			'orange'      => esc_html__( 'Orange', 'travel-gem-pro' ),
			'purple'      => esc_html__( 'Purple', 'travel-gem-pro' ),
			'red'         => esc_html__( 'Red', 'travel-gem-pro' ),
			'sky-blue'    => esc_html__( 'Sky Blue', 'travel-gem-pro' ),
		);

		return $output;
	}

endif;

if ( ! function_exists( 'travel_gem_get_web_fonts' ) ) :

	/**
	 * Returns web font options.
	 *
	 * @since 1.0.0
	 */
	function travel_gem_get_web_fonts() {

		$choices = array(
			'philosopher' => array(
				'name'  => 'Philosopher',
				'label' => "'Philosopher', sans-serif",
				),
			'open-sans' => array(
				'name'  => 'Open Sans',
				'label' => "'Open Sans', sans-serif",
				),
			'pt-sans' => array(
				'name'  => 'PT Sans',
				'label' => "'PT Sans', sans-serif",
				),
			'merriweather-sans' => array(
				'name'  => 'Merriweather Sans',
				'label' => "'Merriweather Sans', sans-serif",
				),
			'montserrat' => array(
				'name'  => 'Montserrat',
				'label' => "'Montserrat', sans-serif",
				),
			'roboto' => array(
				'name'  => 'Roboto',
				'label' => "'Roboto', sans-serif",
				),
			'arizonia' => array(
				'name'  => 'Arizonia',
				'label' => "'Arizonia', cursive",
				),
			'poppins' => array(
				'name'  => 'Poppins',
				'label' => "'Poppins', sans-serif",
				),
			'raleway' => array(
				'name'  => 'Raleway',
				'label' => "'Raleway', sans-serif",
				),
			'droid-sans' => array(
				'name'  => 'Droid Sans',
				'label' => "'Droid Sans', sans-serif",
				),
			'noto-sans' => array(
				'name'  => 'Noto Sans',
				'label' => "'Noto Sans', sans-serif",
				),
			'lato' => array(
				'name'  => 'Lato',
				'label' => "'Lato', sans-serif",
				),
			'dosis' => array(
				'name'  => 'Dosis',
				'label' => "'Dosis', sans-serif",
				),
			'slabo-27px' => array(
				'name'  => 'Slabo 27px',
				'label' => "'Slabo 27px', serif",
				),
			'oswald' => array(
				'name'  => 'Oswald',
				'label' => "'Oswald', sans-serif",
				),
			'pt-sans-narrow' => array(
				'name'  => 'PT Sans Narrow',
				'label' => "'PT Sans Narrow', sans-serif",
				),
			'josefin-slab' => array(
				'name'  => 'Josefin Slab',
				'label' => "'Josefin Slab', serif",
				),
			'alegreya' => array(
				'name'  => 'Alegreya',
				'label' => "'Alegreya', serif",
				),
			'exo' => array(
				'name'  => 'Exo',
				'label' => "'Exo', sans-serif",
				),
			'signika' => array(
				'name'  => 'Signika',
				'label' => "'Signika', sans-serif",
				),
			'lobster' => array(
				'name'  => 'Lobster',
				'label' => "'Lobster', cursive",
				),
			'indie-flower' => array(
				'name'  => 'Indie Flower',
				'label' => "'Indie Flower', cursive",
				),
			'shadows-into-light' => array(
				'name'  => 'Shadows Into Light',
				'label' => "'Shadows Into Light', cursive",
				),
			'kaushan-script' => array(
				'name'  => 'Kaushan Script',
				'label' => "'Kaushan Script', cursive",
				),
			'dancing-script' => array(
				'name'  => 'Dancing Script',
				'label' => "'Dancing Script', cursive",
				),
			'fredericka-the-great' => array(
				'name'  => 'Fredericka the Great',
				'label' => "'Fredericka the Great', cursive",
				),
			'covered-by-your-grace' => array(
				'name'  => 'Covered By Your Grace',
				'label' => "'Covered By Your Grace', cursive",
				),
			);

		$choices = apply_filters( 'travel_gem_filter_web_fonts', $choices );

		if ( ! empty( $choices ) ) {
			ksort( $choices );
		}

		return $choices;
	}

endif;

if ( ! function_exists( 'travel_gem_get_os_fonts' ) ) :

	/**
	 * Returns OS font options.
	 *
	 * @since 1.0.0
	 */
	function travel_gem_get_os_fonts() {

		$choices = array(
			'arial' => array(
				'name'  => 'Arial',
				'label' => "'Arial', sans-serif",
				),
			'georgia' => array(
				'name'  => 'Georgia',
				'label' => "'Georgia', serif",
				),
			'cambria' => array(
				'name'  => 'Cambria',
				'label' => "'Cambria', Georgia, serif",
				),
			'tahoma' => array(
				'name'  => 'Tahoma',
				'label' => "'Tahoma', Geneva, sans-serif",
				),
			'sans-serif' => array(
				'name'  => 'Sans Serif',
				'label' => "'Sans Serif', Arial",
				),
			'verdana' => array(
				'name'  => 'Verdana',
				'label' => "'Verdana', Geneva, sans-serif",
				),
			);

		$choices = apply_filters( 'travel_gem_filter_os_fonts', $choices );

		if ( ! empty( $choices ) ) {
			ksort( $choices );
		}

		return $choices;
	}

endif;

if( ! function_exists( 'travel_gem_get_customizer_font_options' ) ) :

	/**
	 * Returns Customizer font options.
	 *
	 * @since 1.0.0
	 */
	function travel_gem_get_customizer_font_options() {

		$web_fonts = travel_gem_get_web_fonts();
		$os_fonts  = travel_gem_get_os_fonts();

		$web_fonts = array_merge( $web_fonts, $os_fonts );

		if ( ! empty( $web_fonts ) ) {
			ksort( $web_fonts );
		}

		$choices = array();

		if ( ! empty( $web_fonts ) ) {
			foreach ( $web_fonts as $k => $v ) {
				$choices[$k] = esc_html( $v['label'] );
			}
		}

		return $choices;
	}

endif;

if ( ! function_exists( 'travel_gem_get_font_family_from_key' ) ) :

	/**
	 * Returns font family from font slug.
	 *
	 * @since 1.0.0
	 *
	 * @param string $key Font slug.
	 * @return string Font name.
	 */
	function travel_gem_get_font_family_from_key( $key ) {

		$output = '';

		$web_fonts = travel_gem_get_web_fonts();
		$os_fonts  = travel_gem_get_os_fonts();

		$fonts = array_merge( $web_fonts, $os_fonts );

		if ( isset( $fonts[ $key ] ) ) {
			$output = $fonts[ $key ]['label'];
		}

		return $output;
	}

endif;

if ( ! function_exists( 'travel_gem_get_font_family_theme_settings_options' ) ) :

	/**
	 * Returns font family theme settings options.
	 *
	 * @since 1.0.0
	 */
	function travel_gem_get_font_family_theme_settings_options() {

		$choices = array(
			'font_site_title' => array(
				'label'   => esc_html__( 'Site Title', 'travel-gem-pro' ),
				'default' => 'poppins',
				),
			'font_site_tagline' => array(
				'label'   => esc_html__( 'Site Tagline', 'travel-gem-pro' ),
				'default' => 'roboto',
				),
			'font_site_default' => array(
				'label'   => esc_html__( 'Default', 'travel-gem-pro' ),
				'default' => 'roboto',
				),
			'font_content_title' => array(
				'label'   => esc_html__( 'Content Title', 'travel-gem-pro' ),
				'default' => 'poppins',
				),
			'font_content_body' => array(
				'label'   => esc_html__( 'Content Body', 'travel-gem-pro' ),
				'default' => 'roboto',
				),
			'font_heading_tags' => array(
				'label'   => esc_html__( 'Heading Tags', 'travel-gem-pro' ),
				'default' => 'poppins',
				),
			'font_navigation' => array(
				'label'   => esc_html__( 'Navigation', 'travel-gem-pro' ),
				'default' => 'roboto',
				),
			);

		return $choices;
	}

endif;

